===============
Word Enrichment
===============

.. figure:: icons/wordenrichment.png

Word enrichment analysis for selected documents.

Signals
-------

**Inputs**:

-  **Data**

Corpus instance.

-  **Selected Data**

Selected instances from corpus.

**Outputs**:

-  (None)

Description
-----------

No description yet for this widget.

Example
-------

No example yet for this widget.
